"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Sequence = void 0;
const files_1 = require("../files");
const log_1 = require("../log");
class Sequence {
    constructor(camera, fd, display, ffprobe, send) {
        this.current = null;
        this.info = null;
        this.images = [];
        this.log = (0, log_1.createLog)('seq');
        this.camera = camera;
        this.fd = fd;
        this.display = display;
        this.ffprobe = ffprobe;
        this.send = send;
    }
    start() {
        this.running = true;
    }
    stop() {
        this.running = false;
    }
    isRunning() {
        return this.running;
    }
    load(seq) {
        this.current = seq;
        this.enumerate();
        this.send({ cmd: 'select', sequence: seq.hash });
    }
    async enumerate() {
        let screen;
        if (this.current === null) {
            this.log.error('Cannot enumerate sequence because it is not set');
            return;
        }
        try {
            this.images = await files_1.Files.enumerateSequence(this.current.path);
        }
        catch (err) {
            this.log.error(`Error enumerating images in sequence: ${this.current.name}`, err);
            return;
        }
        this.log.info(`Sequence ${this.current.name} contains ${this.images.length} image${this.images.length === 1 ? '' : 's'}`);
        if (this.images.length > 0) {
            this.info = await this.ffprobe.info(this.images[0].path);
        }
        if (this.info !== null) {
            screen = this.display.getScreen();
            this.display.setSource(this.info.width, this.info.height);
            this.log.info(`Screen   : ${screen.width},${screen.height}`);
            this.log.info(`Sequence : ${this.info.width},${this.info.height}`);
            this.log.info(`Display  : ${JSON.stringify(this.display.getDimensions())}`);
        }
    }
    unload() {
        this.current = null;
        this.info = null;
        this.images = [];
    }
    getState() {
        return {
            hash: this.current.hash,
            name: this.current.name,
            progress: this.progress
        };
    }
}
exports.Sequence = Sequence;
//# sourceMappingURL=index.js.map